@@ -117,7 +117,15 @@ class HdfTreePopupMenu(wx.Menu):
     wxTree,wxNode=self.wxObjSrc
     lbl=wxTree.GetItemText(wxNode)
     hid=wxTree.GetPyData(wxNode)
-    fnMatRoi='/scratch/detectorData/cSAXS_2013_10_e14608_georgiadis_3D_for_Marianne/analysis/data/pilatus_integration_mask.mat'    
+    
+    dlg = wx.FileDialog(wxTree, "Choose ROI mask file (e.g. pilatus_integration_mask.mat)", os.getcwd(), '','MATLAB files (*.mat)|*.mat|all (*.*)|*.*', wx.OPEN|wx.FD_CHANGE_DIR)
+    if dlg.ShowModal() == wx.ID_OK:
+      fnMatRoi = dlg.GetPath()
+      print 'OnOpen',fnMatRoi
+    dlg.Destroy()       
+    if not fnMatRoi:
+      return      
+    #fnMatRoi='/scratch/detectorData/cSAXS_2013_10_e14608_georgiadis_3D_for_Marianne/analysis/data/pilatus_integration_mask.mat'    
     frame=ProcRoiStatFrame(wxTree,lbl,hid,fnMatRoi)
     frame.Show(True)     
     
@@ -180,7 +188,7 @@ class HdfViewerFrame(wx.Frame):
 
   def OpenFile(self,fnHDF):
     try:
-      self.fid=h5py.h5f.open(fnHDF)
+      self.fid=h5py.h5f.open(fnHDF,flags=h5py.h5f.ACC_RDONLY)
     except IOError as e:
       sys.stderr.write('Unable to open File: '+fnHDF+'\n')
     else: 
@@ -325,11 +333,18 @@ class HdfViewerFrame(wx.Frame):
     except ValueError as e:
       pass
     else:
-      txt+='Attributes:%d\n'%numAttr
+      if numAttr>20:
+        txt+='Attributes:%d (too many to show)\n'%numAttr
+      else:
+        txt+='Attributes:%d\n'%numAttr
+        for idxAttr in range(numAttr):
+          aid=h5py.h5a.open(hid,index=idxAttr)
+          txt+='\t'+aid.name+'\t'+str(GetAttrVal(aid))+'\n'
+    val=None
     if t==h5py.h5g.GroupID:
       pass
     elif t==h5py.h5d.DatasetID:
-      txt+='shape: '+str(hid.shape)+'\n'
+      txt+='\nshape: '+str(hid.shape)+'\n'
       tt=hid.get_type()
       ttt=type(tt)
       if ttt==h5py.h5t.TypeCompoundID:
@@ -358,9 +373,12 @@ class HdfViewerFrame(wx.Frame):
         try: v=func(pl)
         except ValueError as e: pass
         else:txt+=tx+':'+str(v)+'\n'
-      if hid.shape==(1,):
-        data=h5py.Dataset(hid)
-        txt+='value:'+str(data[0])+'\n'
+        
+      if hid.shape==() or np.prod(hid.shape)<10: #show up to max. 10 element arrays
+      #if  ttt==h5py.h5t.TypeStringID or hid.shape==() or hid.shape==(1,):
+        ds=h5py.Dataset(hid)
+        txt+='Value:\n\t'+str(ds.value)+'\n'
+
     return txt
     
   def OnSelChanged(self, event):
@@ -375,13 +393,11 @@ class HdfViewerFrame(wx.Frame):
 if __name__ == '__main__':
   def GetArgs():   
     import sys,argparse #since python 2.7
-    fnHDF='/scratch/detectorData/e14472_00033.hdf5'
-
-    exampleCmd='--hdfFile='+fnHDF    
+    exampleCmd='/scratch/detectorData/e14472_00033.hdf5'
     parser = argparse.ArgumentParser(formatter_class=argparse.RawDescriptionHelpFormatter,
                                      description=__doc__,
                                      epilog='Example:\n'+os.path.basename(sys.argv[0])+' '+exampleCmd+'\n ')
-    parser.add_argument('hdfFile',   nargs='?', default=fnHDF, help='the hdf5 to show')
+    parser.add_argument('hdfFile',   nargs='?', help='the hdf5 to show')
     
     args = parser.parse_args()
     return args
@@ -390,7 +406,8 @@ if __name__ == '__main__':
     def OnInit(self):
       args=GetArgs()
       frame = HdfViewerFrame(None, 'h5pyViewer')
-      frame.OpenFile(args.hdfFile)
+      if args.hdfFile:
+        frame.OpenFile(args.hdfFile)
       frame.Show(True)
       self.SetTopWindow(frame)
       return True
